# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/clob/liquidations_config.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'dydxprotocol/clob/liquidations_config.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+dydxprotocol/clob/liquidations_config.proto\x12\x11\x64ydxprotocol.clob\x1a\x14gogoproto/gogo.proto\"\xa0\x02\n\x12LiquidationsConfig\x12\x1f\n\x17max_liquidation_fee_ppm\x18\x01 \x01(\r\x12K\n\x15position_block_limits\x18\x02 \x01(\x0b\x32&.dydxprotocol.clob.PositionBlockLimitsB\x04\xc8\xde\x1f\x00\x12O\n\x17subaccount_block_limits\x18\x03 \x01(\x0b\x32(.dydxprotocol.clob.SubaccountBlockLimitsB\x04\xc8\xde\x1f\x00\x12K\n\x15\x66illable_price_config\x18\x04 \x01(\x0b\x32&.dydxprotocol.clob.FillablePriceConfigB\x04\xc8\xde\x1f\x00\"l\n\x13PositionBlockLimits\x12(\n min_position_notional_liquidated\x18\x01 \x01(\x04\x12+\n#max_position_portion_liquidated_ppm\x18\x02 \x01(\r\"]\n\x15SubaccountBlockLimits\x12\x1f\n\x17max_notional_liquidated\x18\x01 \x01(\x04\x12#\n\x1bmax_quantums_insurance_lost\x18\x02 \x01(\x04\"h\n\x13\x46illablePriceConfig\x12!\n\x19\x62\x61nkruptcy_adjustment_ppm\x18\x01 \x01(\r\x12.\n&spread_to_maintenance_margin_ratio_ppm\x18\x02 \x01(\rB8Z6github.com/dydxprotocol/v4-chain/protocol/x/clob/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.clob.liquidations_config_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z6github.com/dydxprotocol/v4-chain/protocol/x/clob/types'
  _globals['_LIQUIDATIONSCONFIG'].fields_by_name['position_block_limits']._loaded_options = None
  _globals['_LIQUIDATIONSCONFIG'].fields_by_name['position_block_limits']._serialized_options = b'\310\336\037\000'
  _globals['_LIQUIDATIONSCONFIG'].fields_by_name['subaccount_block_limits']._loaded_options = None
  _globals['_LIQUIDATIONSCONFIG'].fields_by_name['subaccount_block_limits']._serialized_options = b'\310\336\037\000'
  _globals['_LIQUIDATIONSCONFIG'].fields_by_name['fillable_price_config']._loaded_options = None
  _globals['_LIQUIDATIONSCONFIG'].fields_by_name['fillable_price_config']._serialized_options = b'\310\336\037\000'
  _globals['_LIQUIDATIONSCONFIG']._serialized_start=89
  _globals['_LIQUIDATIONSCONFIG']._serialized_end=377
  _globals['_POSITIONBLOCKLIMITS']._serialized_start=379
  _globals['_POSITIONBLOCKLIMITS']._serialized_end=487
  _globals['_SUBACCOUNTBLOCKLIMITS']._serialized_start=489
  _globals['_SUBACCOUNTBLOCKLIMITS']._serialized_end=582
  _globals['_FILLABLEPRICECONFIG']._serialized_start=584
  _globals['_FILLABLEPRICECONFIG']._serialized_end=688
# @@protoc_insertion_point(module_scope)
