# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/vault/genesis.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'dydxprotocol/vault/genesis.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.dydxprotocol.vault import params_pb2 as dydxprotocol_dot_vault_dot_params__pb2
from v4_proto.dydxprotocol.vault import share_pb2 as dydxprotocol_dot_vault_dot_share__pb2
from v4_proto.dydxprotocol.vault import vault_pb2 as dydxprotocol_dot_vault_dot_vault__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n dydxprotocol/vault/genesis.proto\x12\x12\x64ydxprotocol.vault\x1a\x14gogoproto/gogo.proto\x1a\x1f\x64ydxprotocol/vault/params.proto\x1a\x1e\x64ydxprotocol/vault/share.proto\x1a\x1e\x64ydxprotocol/vault/vault.proto\"\x90\x03\n\x0cGenesisState\x12\x39\n\x0ctotal_shares\x18\x01 \x01(\x0b\x32\x1d.dydxprotocol.vault.NumSharesB\x04\xc8\xde\x1f\x00\x12:\n\x0cowner_shares\x18\x02 \x03(\x0b\x32\x1e.dydxprotocol.vault.OwnerShareB\x04\xc8\xde\x1f\x00\x12/\n\x06vaults\x18\x03 \x03(\x0b\x32\x19.dydxprotocol.vault.VaultB\x04\xc8\xde\x1f\x00\x12G\n\x16\x64\x65\x66\x61ult_quoting_params\x18\x04 \x01(\x0b\x32!.dydxprotocol.vault.QuotingParamsB\x04\xc8\xde\x1f\x00\x12L\n\x17\x61ll_owner_share_unlocks\x18\x05 \x03(\x0b\x32%.dydxprotocol.vault.OwnerShareUnlocksB\x04\xc8\xde\x1f\x00\x12\x41\n\x0foperator_params\x18\x06 \x01(\x0b\x32\".dydxprotocol.vault.OperatorParamsB\x04\xc8\xde\x1f\x00\"\x99\x01\n\x05Vault\x12\x33\n\x08vault_id\x18\x01 \x01(\x0b\x32\x1b.dydxprotocol.vault.VaultIdB\x04\xc8\xde\x1f\x00\x12;\n\x0cvault_params\x18\x02 \x01(\x0b\x32\x1f.dydxprotocol.vault.VaultParamsB\x04\xc8\xde\x1f\x00\x12\x1e\n\x16most_recent_client_ids\x18\x03 \x03(\r\"\x8a\x01\n\x0eGenesisStateV6\x12)\n\x06vaults\x18\x02 \x03(\x0b\x32\x19.dydxprotocol.vault.Vault\x12G\n\x16\x64\x65\x66\x61ult_quoting_params\x18\x03 \x01(\x0b\x32!.dydxprotocol.vault.QuotingParamsB\x04\xc8\xde\x1f\x00J\x04\x08\x01\x10\x02\"\x80\x02\n\x07VaultV6\x12-\n\x08vault_id\x18\x01 \x01(\x0b\x32\x1b.dydxprotocol.vault.VaultId\x12\x33\n\x0ctotal_shares\x18\x02 \x01(\x0b\x32\x1d.dydxprotocol.vault.NumShares\x12\x34\n\x0cowner_shares\x18\x03 \x03(\x0b\x32\x1e.dydxprotocol.vault.OwnerShare\x12;\n\x0cvault_params\x18\x04 \x01(\x0b\x32\x1f.dydxprotocol.vault.VaultParamsB\x04\xc8\xde\x1f\x00\x12\x1e\n\x16most_recent_client_ids\x18\x05 \x03(\rB9Z7github.com/dydxprotocol/v4-chain/protocol/x/vault/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.vault.genesis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z7github.com/dydxprotocol/v4-chain/protocol/x/vault/types'
  _globals['_GENESISSTATE'].fields_by_name['total_shares']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['total_shares']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['owner_shares']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['owner_shares']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['vaults']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['vaults']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['default_quoting_params']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['default_quoting_params']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['all_owner_share_unlocks']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['all_owner_share_unlocks']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['operator_params']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['operator_params']._serialized_options = b'\310\336\037\000'
  _globals['_VAULT'].fields_by_name['vault_id']._loaded_options = None
  _globals['_VAULT'].fields_by_name['vault_id']._serialized_options = b'\310\336\037\000'
  _globals['_VAULT'].fields_by_name['vault_params']._loaded_options = None
  _globals['_VAULT'].fields_by_name['vault_params']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATEV6'].fields_by_name['default_quoting_params']._loaded_options = None
  _globals['_GENESISSTATEV6'].fields_by_name['default_quoting_params']._serialized_options = b'\310\336\037\000'
  _globals['_VAULTV6'].fields_by_name['vault_params']._loaded_options = None
  _globals['_VAULTV6'].fields_by_name['vault_params']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE']._serialized_start=176
  _globals['_GENESISSTATE']._serialized_end=576
  _globals['_VAULT']._serialized_start=579
  _globals['_VAULT']._serialized_end=732
  _globals['_GENESISSTATEV6']._serialized_start=735
  _globals['_GENESISSTATEV6']._serialized_end=873
  _globals['_VAULTV6']._serialized_start=876
  _globals['_VAULTV6']._serialized_end=1132
# @@protoc_insertion_point(module_scope)
